@@ -1,6 +1,6 @@
 package WWW::Google::PageSpeedOnline;
 
-$WWW::Google::PageSpeedOnline::VERSION   = '0.25';
+$WWW::Google::PageSpeedOnline::VERSION   = '0.26';
 $WWW::Google::PageSpeedOnline::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ WWW::Google::PageSpeedOnline - Interface to Google Page Speed Online API.
 
 =head1 VERSION
 
-Version 0.25
+Version 0.26
 
 =cut
 
@@ -26,7 +26,7 @@ use WWW::Google::PageSpeedOnline::Result;
 use WWW::Google::PageSpeedOnline::Result::Rule;
 
 use Moo;
-use namespace::clean;
+use namespace::autoclean;
 extends 'WWW::Google::UserAgent';
 
 has prettyprint => (is => 'ro', isa => TrueFalse, default => sub { 'true'    });
