@@ -1,6 +1,6 @@
 package WWW::Google::PageSpeedOnline::Advise;
 
-$WWW::Google::PageSpeedOnline::Advise::VERSION   = '0.25';
+$WWW::Google::PageSpeedOnline::Advise::VERSION   = '0.26';
 $WWW::Google::PageSpeedOnline::Advise::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,13 +9,13 @@ WWW::Google::PageSpeedOnline::Advise - Placeholder for the advise of L<WWW::Goog
 
 =head1 VERSION
 
-Version 0.25
+Version 0.26
 
 =cut
 
 use 5.006;
 use Moo;
-use namespace::clean;
+use namespace::autoclean;
 
 has id     => (is => 'ro');
 has header => (is => 'ro');
